/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLBaseFontElement.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLBaseFontElement.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLBaseFontElement.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLBaseFontElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLBaseFontElement::GDOMHTMLBaseFontElement(PassRefPtr<WebCore::HTMLBaseFontElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLBaseFontElement.h"
#include <gdom/GdomHTMLBaseFontElement.h>
#include <gdom/PrivateGdomHTMLBaseFontElement.h>
#include <gdom/PrivateIntGdomHTMLBaseFontElement.h>
#include <gdom/GdomHTMLBaseFontElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLBaseFontElement, gdom_html_base_font_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLBaseFontElementPrivate {
    class WebCore::HTMLBaseFontElement *item;
};

#define GDOM_HTML_BASE_FONT_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_BASE_FONT_ELEMENT, GdomHTMLBaseFontElementPrivate))
*/
G_END_DECLS
WebCore::HTMLBaseFontElement *
gdom_html_base_font_element_get_private(GdomHTMLBaseFontElement *request)
{
    GDOMHTMLBaseFontElement *res;
    res = static_cast<GDOMHTMLBaseFontElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLBaseFontElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_COLOR,
    PROP_FACE,
    PROP_SIZE,
};


static void gdom_html_base_font_element_finalize(GObject* object)
{
    /*GdomHTMLBaseFontElement* request = GDOM_HTML_BASE_FONT_ELEMENT(object);*/
    /*GdomHTMLBaseFontElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_base_font_element_parent_class)->finalize(object);
}

static void gdom_html_base_font_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLBaseFontElement *self = GDOM_HTML_BASE_FONT_ELEMENT(object);
    WebCore::HTMLBaseFontElement * gself = (gdom_html_base_font_element_get_private(self));
    switch (prop_id) {
     case PROP_COLOR:
    {
         gself->setColor(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_FACE:
    {
         gself->setFace(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_SIZE:
    {
         gself->setSize((g_value_get_long (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_base_font_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLBaseFontElement *self = GDOM_HTML_BASE_FONT_ELEMENT(object);
    WebCore::HTMLBaseFontElement * gself = (gdom_html_base_font_element_get_private(self));
    switch (prop_id) {
    case PROP_COLOR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->color()));
         break;
    }
    case PROP_FACE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->face()));
         break;
    }
    case PROP_SIZE:
    {
         g_value_set_long (value, gself->size());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_base_font_element_class_init(GdomHTMLBaseFontElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_base_font_element_finalize;
    g_klass->set_property = gdom_html_base_font_element__set_property_fn;
    g_klass->get_property = gdom_html_base_font_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_COLOR,
            g_param_spec_string ("color", /* name */
                "html_base_font_element_color", /* short description */
                "read-write  gchar * HTMLBaseFontElement.color", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_FACE,
            g_param_spec_string ("face", /* name */
                "html_base_font_element_face", /* short description */
                "read-write  gchar * HTMLBaseFontElement.face", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SIZE,
            g_param_spec_long ("size", /* name */
                "html_base_font_element_size", /* short description */
                "read-write  glong HTMLBaseFontElement.size", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLBaseFontElementPrivate));*/
}

static void gdom_html_base_font_element_init(GdomHTMLBaseFontElement* request)
{
    /*GdomHTMLBaseFontElementPrivate* priv = GDOM_HTML_BASE_FONT_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

